@@ -24,7 +24,9 @@
 class K3bExternalBin;
 class K3bProcess;
 class TDEProcess;
-class K3bDevice::Device;
+namespace K3bDevice {
+    class Device;
+}
 class TQSocket;
 
 
