@@ -18,13 +18,13 @@
 
 #include <k3bmovixdoc.h>
 #include "k3b_export.h"
-class KConfig;
+class TDEConfig;
 
 
 class LIBK3B_EXPORT K3bMovixDvdDoc : public K3bMovixDoc
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bMovixDvdDoc( TQObject* parent = 0 );
