@@ -23,16 +23,16 @@
 #include <k3bglobals.h>
 #include <k3bfilesysteminfo.h>
 
-#include <klocale.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kurlrequester.h>
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <kio/global.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeio/global.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 
 #include <tqlayout.h>
 #include <tqcheckbox.h>
@@ -212,7 +212,7 @@ void K3bVideoDVDRippingDialog::populateTitleView( const TQValueList<int>& titles
     //
     ri.audioStream = 0;
     for( unsigned int i = 0; i < m_dvd[*it-1].numAudioStreams(); ++i ) {
-      if( m_dvd[*it-1].audioStream(i).langCode() == KGlobal::locale()->language() &&
+      if( m_dvd[*it-1].audioStream(i).langCode() == TDEGlobal::locale()->language() &&
 	  m_dvd[*it-1].audioStream(i).format() != K3bVideoDVD::AUDIO_FORMAT_DTS ) {
 	ri.audioStream = i;
 	break;
@@ -226,7 +226,7 @@ void K3bVideoDVDRippingDialog::populateTitleView( const TQValueList<int>& titles
 	.arg( m_dvd[*it-1].audioStream(i).channels() )
 	.arg( m_dvd[*it-1].audioStream(i).langCode().isEmpty()
 	      ? i18n("unknown language")
-	      : KGlobal::locale()->twoAlphaToLanguageName( m_dvd[*it-1].audioStream(i).langCode() ) )
+	      : TDEGlobal::locale()->twoAlphaToLanguageName( m_dvd[*it-1].audioStream(i).langCode() ) )
 	.arg( m_dvd[*it-1].audioStream(i).codeExtension() != K3bVideoDVD::AUDIO_CODE_EXT_UNSPECIFIED
 	      ? TQString(" ") + K3bVideoDVD::audioCodeExtensionString( m_dvd[*it-1].audioStream(i).codeExtension() )
 	      : TQString() );
@@ -272,7 +272,7 @@ void K3bVideoDVDRippingDialog::slotUpdateFilenames()
 void K3bVideoDVDRippingDialog::slotUpdateFilesizes()
 {
   double bitrate = (double)m_w->m_spinVideoBitrate->value();
-  KIO::filesize_t overallSize = 0ULL;
+  TDEIO::filesize_t overallSize = 0ULL;
 
   // update file sizes
   for( TQMap<TQCheckListItem*, K3bVideoDVDRippingJob::TitleRipInfo>::iterator it = m_titleRipInfos.begin();
@@ -281,13 +281,13 @@ void K3bVideoDVDRippingDialog::slotUpdateFilesizes()
     double sec = m_dvd[it.data().title-1].playbackTime().totalSeconds();
 
     // estimate the filesize
-    KIO::filesize_t size = (KIO::filesize_t)( sec * bitrate * 1000.0 / 8.0 );
+    TDEIO::filesize_t size = (TDEIO::filesize_t)( sec * bitrate * 1000.0 / 8.0 );
 
     // add audio stream size
     // FIXME: consider AC3 passthrough
-    size += (KIO::filesize_t)( sec * m_w->selectedAudioBitrate() / 8.0 * 1024.0 );
+    size += (TDEIO::filesize_t)( sec * m_w->selectedAudioBitrate() / 8.0 * 1024.0 );
 
-    it.key()->setText( 2, KIO::convertSize( size ) );
+    it.key()->setText( 2, TDEIO::convertSize( size ) );
 
     overallSize += size;
   }
@@ -436,7 +436,7 @@ TQString K3bVideoDVDRippingDialog::createFilename( const K3bVideoDVDRippingJob::
 	break;
       case PATTERN_LANGUAGE_NAME:
 	if( title.numAudioStreams() > 0 )
-	  f.append( KGlobal::locale()->twoAlphaToLanguageName( title.audioStream( info.audioStream ).langCode() ) );
+	  f.append( TDEGlobal::locale()->twoAlphaToLanguageName( title.audioStream( info.audioStream ).langCode() ) );
 	break;
       case PATTERN_AUDIO_FORMAT:
 	// FIXME: what about MPEG audio streams?
@@ -471,7 +471,7 @@ TQString K3bVideoDVDRippingDialog::createFilename( const K3bVideoDVDRippingJob::
 	  f.append( "16:9" );
 	break;
       case PATTERN_CURRENT_DATE:
-	f.append( KGlobal::locale()->formatDate( TQDate::currentDate() ) );
+	f.append( TDEGlobal::locale()->formatDate( TQDate::currentDate() ) );
 	break;
       default:
 	f.append( pattern[i-1] );
@@ -514,7 +514,7 @@ void K3bVideoDVDRippingDialog::loadK3bDefaults()
 }
 
 
-void K3bVideoDVDRippingDialog::loadUserDefaults( KConfigBase* c )
+void K3bVideoDVDRippingDialog::loadUserDefaults( TDEConfigBase* c )
 {
   m_w->m_spinVideoBitrate->setValue( c->readNumEntry( "video bitrate", 1200 ) );
   m_w->m_checkTwoPassEncoding->setChecked( c->readBoolEntry( "two pass encoding", true ) );
@@ -532,7 +532,7 @@ void K3bVideoDVDRippingDialog::loadUserDefaults( KConfigBase* c )
 }
 
 
-void K3bVideoDVDRippingDialog::saveUserDefaults( KConfigBase* c )
+void K3bVideoDVDRippingDialog::saveUserDefaults( TDEConfigBase* c )
 {
   c->writeEntry( "video bitrate", m_w->m_spinVideoBitrate->value() );
   c->writeEntry( "two pass encoding", m_w->m_checkTwoPassEncoding->isChecked() );
